package com.bweb.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.entity.*;
import com.hai.model.ResponseData;
import com.hai.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping(value = "/tyAgentPrice")
@Api(value = "订单接口")
public class HighTyAgentPriceController {

    private static Logger log = LoggerFactory.getLogger(HighTyAgentPriceController.class);

    @Resource
    private HighTyAgentPriceService tyAgentPriceService;

    @Resource
    private HighTyAgentOilStationService tyAgentOilStationService;

    @Resource
    private HighMerchantStoreService merchantStoreService;

    @Resource
    private HighGasOilPriceService gasOilPriceService;

    @Resource
    private HighGasDiscountOilPriceService gasDiscountOilPriceService;

    @Resource
    private CommonService commonService;

    @Resource
    private UserCenter userCenter;

    @RequestMapping(value = "/editPrice", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "编辑价格")
    public ResponseData editPrice(@RequestBody JSONArray bodyArray) {
        try {

            if (bodyArray == null || bodyArray.size() == 0) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMPETENCE_INSUFFICIENT, "");
            }

            for (Object obj : bodyArray) {
                JSONObject body = (JSONObject)JSONObject.toJSON(obj);
                if (body.getLong("tyAgentOilStationId") == null
                        || StringUtils.isBlank(body.getString("oilNoName"))
                        || StringUtils.isBlank(body.getString("oilNo"))
                        || body.getBigDecimal("priceRate") == null) {
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.COMPETENCE_INSUFFICIENT, "");
                }

                // 查询油站
                HighTyAgentPrice agentOilStation = tyAgentPriceService.getDetail(body.getLong("tyAgentOilStationId"), body.getString("oilNo"));
                if (agentOilStation == null) {
                    agentOilStation = new HighTyAgentPrice();
                    agentOilStation.setTyAgentOilStationId(body.getLong("tyAgentOilStationId"));
                    agentOilStation.setOilNoName(body.getString("oilNoName"));
                    agentOilStation.setOilNo(body.getString("oilNo"));
                    agentOilStation.setPriceRate(body.getBigDecimal("priceRate"));
                } else {
                    agentOilStation.setPriceRate(body.getBigDecimal("priceRate"));
                }
                tyAgentPriceService.editTyAgentPrice(agentOilStation);
            }


            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("HighTyAgentPriceController --> editPrice() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/getOilStationPrice", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "油站价格")
    public ResponseData getOilStationPrice(@RequestParam(name = "oilStationId", required = true) Long oilStationId) {
        try {

            HighTyAgentOilStation station = tyAgentOilStationService.getDetailByOilStationId(oilStationId);
            if (station == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "加油站未分配，无法查看");
            }

            List<HighGasOilPrice> oilPriceList = gasOilPriceService.getGasOilPriceByStore(oilStationId);
            if (oilPriceList == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "此加油站，暂无法配置");
            }
            List<Map<String, Object>> oilPriceMapList = new ArrayList<>();
            Map<String, Object> oilPriceMap;

            for (HighGasOilPrice price : oilPriceList) {
                oilPriceMap = new HashMap<>();
                oilPriceMap.put("tyAgentOilStationId", station.getId());
                oilPriceMap.put("oilNo", price.getOilNo());
                oilPriceMap.put("oilNoName", price.getOilNoName());
                oilPriceMap.put("lowPrice", commonService.getDictionaryCodeName("TY_AGENT_OIL_STATION_LOW_PRICE", price.getOilNo().toString()));

                // 价格
                HighTyAgentPrice priceRate = tyAgentPriceService.getDetail(station.getId(), price.getOilNo().toString());
                if (priceRate == null) {
                    oilPriceMap.put("priceRate", MapUtils.getLong(oilPriceMap, "lowPrice"));
                } else {
                    oilPriceMap.put("priceRate", priceRate.getPriceRate());
                }
                oilPriceMapList.add(oilPriceMap);
            }

            return ResponseMsgUtil.success(oilPriceMapList);

        } catch (Exception e) {
            log.error("HighTyAgentPriceController --> getOilStationPrice() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
